@@ -41,7 +41,7 @@ def has_time_passed(last_time, seconds: int = 5) -> bool:
 
 
 class BotClient:
-    BASE_URL = "https://messengerg2b1.iranlms.ir/v3/{}/"
+    BASE_URL = "http://botapi.rubika.ir/v3/{}/"
 
     def __init__(
             self,
