@@ -7,11 +7,59 @@ from rubpy.bot.models import Update
 from rubpy.bot.models import InlineMessage
 
 
+def maybe_instance(f):
+    return f() if isinstance(f, type) else f
+
+
 class Filter:
-    async def check(self, update: Union[Update, InlineMessage]) -> bool:
+    async def check(self, update):
+        raise NotImplementedError
+
+    def __and__(self, other):
+        return AndFilter(maybe_instance(self), maybe_instance(other))
+
+    def __or__(self, other):
+        return OrFilter(maybe_instance(self), maybe_instance(other))
+
+    def __invert__(self):
+        instance = self() if isinstance(self, type) else self
+        return NotFilter(instance)
+
+
+class AndFilter(Filter):
+    def __init__(self, *filters: Filter):
+        self.filters = filters
+
+    async def check(self, update: Union["Update", "InlineMessage"]) -> bool:
+        for f in self.filters:
+            if isinstance(f, type):  # اگر کلاس دادیم
+                f = f()
+            if not await f.check(update):
+                return False
         return True
 
 
+class OrFilter(Filter):
+    def __init__(self, *filters: Filter):
+        self.filters = filters
+
+    async def check(self, update):
+        for f in self.filters:
+            if isinstance(f, type):
+                f = f()
+            if await f.check(update):
+                return True
+        return False
+
+
+class NotFilter(Filter):
+    def __init__(self, f: Filter):
+        self.f = f if not isinstance(f, type) else f()
+
+    async def check(self, update):
+        return not await self.f.check(update)
+
+
 class text(Filter):
     """
     Filter for checking message text content.
@@ -53,46 +101,66 @@ class text(Filter):
     def __init__(self, text: Optional[str] = None, regex: bool = False):
         self.text = text
         self.regex = regex
+        self._compiled = re.compile(text) if regex and text else None
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         text = update.find_key("text")
         if not text:
             return False
-        if not self.text and not self.regex:
+
+        if not self.text:
             return True
-        return bool(re.match(self.text, text)) if self.regex else text == self.text
+
+        if self.regex:
+            return bool(self._compiled.match(text))
+
+        return text == self.text
 
 
 class commands(Filter):
     """
-    Filter for detecting command messages (e.g. /start, /help).
+    Advanced filter for detecting bot commands (e.g. /start, !help, test).
 
-    This filter checks whether the message text starts with one of the specified slash commands.
-    It is useful for handling bot commands in both private and group chats.
+    Features:
+        - Supports multiple command prefixes (default: / and !).
+        - Case-insensitive option.
+        - Matches both exact commands and commands with arguments.
+        - Supports single or multiple commands.
 
     Args:
-        command (Union[str, List[str]]): A single command or list of command names (without the leading slash).
-
-    Returns:
-        bool: True if the message text starts with one of the specified commands.
+        commands (Union[str, List[str]]): Command or list of commands (without prefix).
+        prefixes (List[str], optional): Allowed prefixes (default: ["/", "!"]).
+        case_sensitive (bool, optional): Whether command matching is case-sensitive. Default False.
+        allow_no_prefix (bool, optional): If True, matches commands even without prefix. Default False.
 
     Example:
-        >>> from rubpy import BotClient
-        >>> from rubpy.bot.filters import commands
-        >>>
-        >>> bot = BotClient("your_bot_token")
-        >>>
         >>> @bot.on_update(commands("start"))
         ... async def handle_start(c, update):
-        ...     await c.send_message(update.chat_id, "Welcome to the bot!")
-        >>>
-        >>> @bot.on_update(commands(["help", "about"]))
-        ... async def handle_help_about(c, update):
-        ...     await c.send_message(update.chat_id, "Help or About command detected!")
+        ...     await update.reply("Welcome to the bot!")
+
+        >>> @bot.on_update(commands(["help", "about"], prefixes=["/", ".", "!"]))
+        ... async def handle_help(c, update):
+        ...     await update.reply("Help/About detected!")
+
+        >>> @bot.on_update(commands("test", allow_no_prefix=True))
+        ... async def handle_test(c, update):
+        ...     await update.reply("Matched with or without prefix")
     """
 
-    def __init__(self, command: Union[str, List[str]]):
-        self.commands = [command] if isinstance(command, str) else command
+    def __init__(
+        self,
+        commands: Union[str, List[str]],
+        prefixes: List[str] = ["/"],
+        case_sensitive: bool = False,
+        allow_no_prefix: bool = False,
+    ):
+        self.commands = [commands] if isinstance(commands, str) else commands
+        self.prefixes = prefixes
+        self.case_sensitive = case_sensitive
+        self.allow_no_prefix = allow_no_prefix
+
+        if not case_sensitive:
+            self.commands = [cmd.lower() for cmd in self.commands]
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         text = (
@@ -102,7 +170,29 @@ class commands(Filter):
         )
         if not text:
             return False
-        return any(text.startswith(f"/{cmd}") for cmd in self.commands)
+
+        # prepare text for matching
+        check_text = text if self.case_sensitive else text.lower()
+
+        # split into command + args
+        parts = check_text.split(maxsplit=1)
+        command_part = parts[0]
+
+        # check with prefixes
+        for cmd in self.commands:
+            for prefix in self.prefixes:
+                if command_part == f"{prefix}{cmd}" or command_part.startswith(
+                    f"{prefix}{cmd}"
+                ):
+                    return True
+
+            # allow matching without prefix
+            if self.allow_no_prefix and (
+                command_part == cmd or command_part.startswith(cmd)
+            ):
+                return True
+
+        return False
 
 
 class update_type(Filter):
@@ -202,6 +292,33 @@ class group(Filter):
         return bool(update.chat_id.startswith("g0"))
 
 
+class channel(Filter):
+    """
+    Filter for detecting messages sent from groups.
+
+    This filter checks whether the sender of the message is of type `'Group'`.
+    It's useful when you want a handler to be triggered only for messages
+    originating from group chats.
+
+    Returns:
+        bool: True if the message was sent from a group, otherwise False.
+
+    Example:
+        >>> from rubpy import BotClient
+        >>> from rubpy.bot.models import Update
+        >>> from rubpy.bot.filters import group
+        >>>
+        >>> bot_client = BotClient("your_bot_token")
+        >>>
+        >>> @bot_client.on_update(group)
+        ... async def handle_group_messages(c, update):
+        ...     await c.send_message(update.chat_id, "This message came from a group!")
+    """
+
+    async def check(self, update: Union[Update, InlineMessage]) -> bool:
+        return bool(update.chat_id.startswith("c0"))
+
+
 class bot(Filter):
     """
     Filter for detecting messages sent by bots.
@@ -614,16 +731,22 @@ class live_location(Filter):
         except KeyError:
             return False
 
+
+class replied(Filter):
+    async def check(self, update):
+        return bool(update.find_key("reply_to_message_id"))
+
+
 class states(Filter):
     """
     Self-contained states filter that stores states in-memory (no external libs).
-    
+
     - Use as a filter instance: `s = states("awaiting_email"); @bot.on_update(s) ...`
     - Also exposes methods to set/get/clear state for a given update:
         await s.set_state_for(update, "awaiting_email", expire=300)
         await s.get_state_for(update)
         await s.clear_state_for(update)
-    
+
     Args:
         targets: None|str|List[str] - states to match (None => match any existing state).
         match_mode: "exact"|"regex"|"contains"|"any" (default "exact")
@@ -656,7 +779,12 @@ class states(Filter):
         assert scope in ("user", "chat", "both")
         self.match_mode = match_mode
         self.scope = scope
-        self.check_keys = check_keys or ["state", "fsm_state", "user_state", "session_state"]
+        self.check_keys = check_keys or [
+            "state",
+            "fsm_state",
+            "user_state",
+            "session_state",
+        ]
         self.auto_clear = auto_clear
         self.set_on_match = set_on_match
         self.default_expire = expire
@@ -676,6 +804,7 @@ class states(Filter):
         old = cls._TTL_TASKS.get(key)
         if old and not old.done():
             old.cancel()
+
         async def _job():
             try:
                 await asyncio.sleep(seconds)
@@ -683,6 +812,7 @@ class states(Filter):
                 cls._TTL_TASKS.pop(key, None)
             except asyncio.CancelledError:
                 return
+
         t = asyncio.create_task(_job())
         cls._TTL_TASKS[key] = t
 
@@ -706,7 +836,12 @@ class states(Filter):
     # -------------------------
     # Public helper APIs
     # -------------------------
-    async def set_state_for(self, update: Union[Update, InlineMessage, Any], value: str, expire: Optional[int] = None):
+    async def set_state_for(
+        self,
+        update: Union[Update, InlineMessage, Any],
+        value: str,
+        expire: Optional[int] = None,
+    ):
         """
         Set a state for the update's scope (user/chat) according to filter.scope.
         """
@@ -716,7 +851,9 @@ class states(Filter):
         for k in klist:
             await self._set_store(k, value, expire or self.default_expire)
 
-    async def get_state_for(self, update: Union[Update, InlineMessage, Any]) -> Optional[str]:
+    async def get_state_for(
+        self, update: Union[Update, InlineMessage, Any]
+    ) -> Optional[str]:
         """Get first available state from storage for the update (according to scope)."""
         klist = self._keys_for_update(update)
         if not klist:
@@ -750,7 +887,11 @@ class states(Filter):
         # fallback to find_key if exists
         try:
             if not sender_id and hasattr(update, "find_key"):
-                sender_id = update.find_key("sender_id") or update.find_key("from_id") or sender_id
+                sender_id = (
+                    update.find_key("sender_id")
+                    or update.find_key("from_id")
+                    or sender_id
+                )
         except Exception:
             pass
         try:
@@ -765,7 +906,9 @@ class states(Filter):
             keys.append(f"chat:{chat_id}")
         return keys
 
-    async def _extract_local_state(self, update: Union[Update, InlineMessage, Any]) -> Optional[str]:
+    async def _extract_local_state(
+        self, update: Union[Update, InlineMessage, Any]
+    ) -> Optional[str]:
         """
         Try to read state directly from update payload keys (without using internal store).
         Returns first found string value or None.
@@ -786,7 +929,11 @@ class states(Filter):
                     return str(val)
         # also look inside aux_data if present
         try:
-            aux = update.find_key("aux_data") if hasattr(update, "find_key") else getattr(update, "aux_data", None)
+            aux = (
+                update.find_key("aux_data")
+                if hasattr(update, "find_key")
+                else getattr(update, "aux_data", None)
+            )
             if aux and isinstance(aux, dict):
                 for k in ("state", "fsm_state"):
                     v = aux.get(k)
@@ -831,6 +978,8 @@ class states(Filter):
             if self.auto_clear:
                 await self.clear_state_for(update)
             if self.set_on_match:
-                await self.set_state_for(update, self.set_on_match, expire=self.default_expire)
+                await self.set_state_for(
+                    update, self.set_on_match, expire=self.default_expire
+                )
 
-        return matched
\ No newline at end of file
+        return matched
