@@ -5,22 +5,23 @@ import markdownify
 
 # الگوی عبارات منظم برای شناسایی نشانه‌گذاری‌های Markdown
 MARKDOWN_RE = re.compile(
-    r'```([\s\S]*?)```|\*\*(.*?)\*\*|`(.*?)`|__(.*?)__|--(.*?)--|~~(.*?)~~|\|\|(.*?)\|\||\[(.*?)\]\((\S+)\)',
-    flags=re.DOTALL
+    r"```([\s\S]*?)```|\*\*(.*?)\*\*|`(.*?)`|__(.*?)__|--(.*?)--|~~(.*?)~~|\|\|(.*?)\|\||\[(.*?)\]\((\S+)\)",
+    flags=re.DOTALL,
 )
 
 # نگاشت نوع نشانه‌گذاری به گروه مربوطه در الگوی رجکس
 MARKDOWN_TYPES = {
-    '```': ('Pre', 1),
-    '**': ('Bold', 2),
-    '`': ('Mono', 3),
-    '__': ('Italic', 4),
-    '--': ('Underline', 5),
-    '~~': ('Strike', 6),
-    '||': ('Spoiler', 7),
-    '[': ('Link', 8)
+    "```": ("Pre", 1),
+    "**": ("Bold", 2),
+    "`": ("Mono", 3),
+    "__": ("Italic", 4),
+    "--": ("Underline", 5),
+    "~~": ("Strike", 6),
+    "||": ("Spoiler", 7),
+    "[": ("Link", 8),
 }
 
+
 def java_like_length(text: str) -> int:
     """
     محاسبه طول رشته بر اساس واحدهای UTF-16 (شبیه جاوا).
@@ -31,7 +32,8 @@ def java_like_length(text: str) -> int:
     خروجی:
     تعداد واحدهای کاراکتر UTF-16.
     """
-    return len(text.encode('utf-16-be')) // 2
+    return len(text.encode("utf-16-be")) // 2
+
 
 class Markdown:
     """کلاس برای پردازش و استخراج متادیتا از متن Markdown با رفتار شبیه جاوا."""
@@ -74,43 +76,56 @@ class Markdown:
             for prefix, (md_type, group_idx) in MARKDOWN_TYPES.items():
                 if group.startswith(prefix):
                     content = match.group(group_idx)
-                    content_length = java_like_length(content)  # طول محتوای خالص در UTF-16
+                    content_length = java_like_length(
+                        content
+                    )  # طول محتوای خالص در UTF-16
                     meta_data_part = {
-                        'type': md_type,
-                        'from_index': adjusted_start,
-                        'length': content_length
+                        "type": md_type,
+                        "from_index": adjusted_start,
+                        "length": content_length,
                     }
 
-                    if md_type == 'Pre':
+                    if md_type == "Pre":
                         # استخراج زبان برای بلوک کد
-                        lines = content.split('\n', 1)
-                        language = lines[0].strip() if lines[0].strip() else ''
-                        meta_data_part['language'] = language
-                    elif md_type == 'Link':
+                        lines = content.split("\n", 1)
+                        language = lines[0].strip() if lines[0].strip() else ""
+                        meta_data_part["language"] = language
+                    elif md_type == "Link":
                         # پردازش لینک‌ها و منشن‌ها
                         url = match.group(9)
-                        mention_types = {'u': 'User', 'g': 'Group', 'c': 'Channel'}
-                        mention_type = mention_types.get(url[0], 'hyperlink')
+                        mention_types = {"u": "User", "g": "Group", "c": "Channel"}
+                        mention_type = mention_types.get(url[0], "hyperlink")
 
-                        if mention_type == 'hyperlink':
-                            meta_data_part['link'] = {'type': mention_type, 'hyperlink_data': {'url': url}}
+                        if mention_type == "hyperlink":
+                            meta_data_part["link"] = {
+                                "type": mention_type,
+                                "hyperlink_data": {"url": url},
+                            }
                         else:
-                            meta_data_part['type'] = 'MentionText'
-                            meta_data_part['mention_text_object_guid'] = url
-                            meta_data_part['mention_text_object_type'] = mention_type
+                            meta_data_part["type"] = "MentionText"
+                            meta_data_part["mention_text_object_guid"] = url
+                            meta_data_part["mention_text_object_type"] = mention_type
 
                     meta_data_parts.append(meta_data_part)
 
                     # جایگزینی نشانه‌گذاری با متن خالص و به‌روزرسانی متن و آفست
-                    markup_length = java_like_length(group)  # طول کل نشانه‌گذاری در UTF-16
-                    char_markup_length = end - start  # طول کل نشانه‌گذاری در کاراکترهای پایتون
-                    current_text = current_text[:adjusted_char_start] + content + current_text[end - char_offset:]
+                    markup_length = java_like_length(
+                        group
+                    )  # طول کل نشانه‌گذاری در UTF-16
+                    char_markup_length = (
+                        end - start
+                    )  # طول کل نشانه‌گذاری در کاراکترهای پایتون
+                    current_text = (
+                        current_text[:adjusted_char_start]
+                        + content
+                        + current_text[end - char_offset :]
+                    )
                     offset += markup_length - content_length
                     char_offset += char_markup_length - len(content)
                     break
 
-        result = {'text': current_text.strip()}
+        result = {"text": current_text.strip()}
         if meta_data_parts:
-            result['metadata'] = {'meta_data_parts': meta_data_parts}
-        
+            result["metadata"] = {"meta_data_parts": meta_data_parts}
+
         return result
